# :fire: FireANTs: Adaptive Riemannian Optimization for Multi-Scale Diffeomorphic Registration

The FireANTs library is a lightweight registration package for Riemannian diffeomorphic registration on GPUs.

## Installation 
To use the FireANTs package, you can either clone the repository and install the package locally or install the package directly from PyPI.
We recommend using a fresh Anaconda/Miniconda environment to install the package.
```
conda create -n fireants python=3.7
```

To install FireANTs locally:
```
git clone https://github.com/rohitrango/fireants
cd fireants
pip install -e .
```

Or to install from PyPI:
```
pip install fireants
```

## Tutorial
